# A61_読者分析チェック - A60読者分析・離脱率最適化完了後のチェックリスト

Version: 1.0.0
Last Updated: 2025-09-11
Type: チェックリスト（A60対向）

対象: A60_読者分析・離脱率最適化.md の運用結果
前提: 分析基盤（ログ/ダッシュボード）と指標定義が稼働

使用タイミング:
- 連載運用中の週次/話次レビュー時

品質チェック（抜粋）:
- [ ] コア指標（PV/読了率/離脱地点）の取得と可視化
- [ ] 離脱原因の仮説と検証（導入/中盤/締め）
- [ ] タイトル/小見出し/前話フックの改善効果測定
- [ ] セグメント別（新規/再訪）の行動差分分析
- [ ] 次の施策が定義され、効果がトラッキング可能

合否判定:
- データに基づく改善サイクルが回っていること。

